import {useState, useEffect} from 'react';
import axios from 'axios';
import './LabsPage.css';
import {labsAPI, collegesAPI, loginPagePath} from "../utils.ts";
import {useNavigate, useLocation} from "react-router-dom";
import {CollegeItem, ResearchLabItem} from "../types.ts";
import LabsList from "../components/LabsList.tsx";
import FilterLabsLinks from "../components/FilterLabsLinks.tsx";

export default function LabsPage() {
    const [researchLabs, setResearchLabs] = useState<ResearchLabItem[]>([]);
    const [colleges, setColleges] = useState<CollegeItem[]>([]);

    const [loading, setLoading] = useState<boolean>(true);
    const [error, setError] = useState<string | null>(null);
    const navigate = useNavigate();
    const location = useLocation();
    const token = sessionStorage.getItem('token');

    useEffect(() => {
        setLoading(true);
        const queryParams = new URLSearchParams(location.search);
        const collegeName = queryParams.get('collegeName') || ''; // Default to empty string if not set
        const majorName = queryParams.get('majorName') || ''; // Default to empty string if not set

        if (!token) {
            setError('No token found, please login');
            setLoading(false);
            navigate(`${loginPagePath}`);
            return;
        }

        axios.get<ResearchLabItem[]>(`${labsAPI}`, {
            headers: {
                'Authorization': `Bearer ${token}`,
            },
            params: {
                collegeName: collegeName || undefined,
                majorName: majorName || undefined,
            }
        })
            .then(response => {
                setResearchLabs(response.data);
            })
            .catch(error => {
                setError(error.message);
            });
        
        setLoading(false);
    }, [location.search, navigate]);


    useEffect(() => {
        if (!token) {
            setError('No token found, please login');
            setLoading(false);
            navigate(`${loginPagePath}`);
            return;
        }
        setLoading(true);

        axios.get<CollegeItem[]>(`${collegesAPI}`, {
            headers: {
                'Authorization': `Bearer ${token}`,
            },
            params: {
                majors: true
            }
        })
            .then(response => {
                setColleges(response.data);
            })
            .catch(error => {
                setError(error.message);
            });
        setLoading(false);
    }, [])

    if (loading) {
        return <div className='labs-page center-content'><h1>Loading...</h1></div>;
    }

    if (error) {
        return <div className='labs-page center-content'><h1>Error: {error}</h1></div>;
    }

    return (
        <div className='labs-page center-content'>
            <div className='labs-nav'>
                <h1 className='labs-nav-title'>Filter Options</h1>
                <FilterLabsLinks colleges={colleges}/>
            </div>
            <div className='labs-content'>
                <h1 className='labs-title'>Research Labs</h1>
                <LabsList researchLabs={researchLabs}/>
            </div>
        </div>
    );
}